# torchtel

torchtel provides OpenTelemetry auto instrumentation for pytorch

## Install from pypi

```bash
$ pip install torchtel
```

You can use it as a python library:

# TODO

## Contributing

Read our contributing guide to learn about our development process, how to propose bugfixes and feature requests, and how to build your changes.

### [Code of Conduct](https://code.fb.com/codeofconduct)

Facebook has adopted a Code of Conduct that we expect project participants to adhere to. Please read [the full text](https://code.fb.com/codeofconduct) so that you can understand what actions will and will not be tolerated.

## Mantainers

clusterscope is actively maintained by [Lucca Bertoncini](https://github.com/luccabb), and [Billy Campoli](https://github.com/tooji).

### License

clusterscope is licensed under the [MIT](./LICENSE) license.
